import type { IWasmAPI, MemoryViewType, WasmBridge, WasmModuleSpec, WasmType } from "@thi.ng/wasm-api";
import { type WasmDom } from "@thi.ng/wasm-api-dom";
import { ObjectIndex } from "@thi.ng/wasm-api/object-index";
import type { ITexture, Shader, ModelSpec as WEBGL_ModelSpec } from "@thi.ng/webgl";
import type { AttribUpdateSpec, WasmWebGLExports, WasmWebGLImports, WebGLContextOpts } from "./api.js";
import { type ModelSpec, type ShaderSpec, type TextureSpec, type UniformValue } from "./generated/api.js";
/**
 * WASM module descriptor for use as dependency object in other module
 * definitions or for direct use with
 * [`WasmBridge`](https://docs.thi.ng/umbrella/wasm-api/classes/WasmBridge.html).
 *
 * @remarks
 * Module defines the following dependencies:
 * - [WasmDomModule](https://docs.thi.ng/umbrella/wasm-api-dom/variables/WasmDomModule.html)
 *
 * See
 * [`WasmModuleSpec`](https://docs.thi.ng/umbrella/wasm-api/interfaces/WasmModuleSpec.html)
 * for more details.
 */
export declare const WasmWebGLModule: WasmModuleSpec<WasmWebGLExports>;
export declare class WasmWebGL implements IWasmAPI<WasmWebGLExports> {
    parent: WasmBridge<WasmWebGLExports>;
    dom: WasmDom;
    contexts: ObjectIndex<WebGL2RenderingContext>;
    models: ObjectIndex<WEBGL_ModelSpec>;
    shaders: ObjectIndex<Shader>;
    textures: ObjectIndex<ITexture>;
    $ShaderSpec: WasmType<ShaderSpec>;
    $ModelSpec: WasmType<ModelSpec>;
    $TextureSpec: WasmType<TextureSpec>;
    $UniformValue: WasmType<UniformValue>;
    $AttribUpdateSpec: WasmType<AttribUpdateSpec>;
    $WebGLContextOpts: WasmType<WebGLContextOpts>;
    init(parent: WasmBridge<WasmWebGLExports>): Promise<boolean>;
    getImports(): WasmWebGLImports;
    /**
     * Shared handler for setting a scalar uniform in a ModelSpec
     *
     * @param modelID
     * @param name
     * @param value
     */
    uniformScalar(modelID: number, name: number, value: number): void;
    uniformVec(modelID: number, name: number, type: MemoryViewType, addr: number, size: number): void;
}
//# sourceMappingURL=gl.d.ts.map